/*
 * @author Phil Zoio
 */
package co.uk.realsolve.holiday.shared;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import java.util.List;

import co.uk.realsolve.holiday.beans.DayCount;
import co.uk.realsolve.holiday.beans.HolidayBooking;

/**
 * Represents service interface to backend, only one single copy since stored in
 * context
 */
public class HolidayService {

	private List holidayBookings;

	static int id;

	public HolidayService() {

		List holidayBooking = getHolidayBookings();

		if (holidayBooking == null) {
			holidayBooking = new ArrayList();
			setHolidayBookings(holidayBooking);

			addHoliday(11.0F, new java.util.Date(), null);
			addHoliday(22.12F, new java.util.Date(), null);
		}
	}

	/** *************** public service methods ******************* */

	/**
	 * Allows you to get all instances - public service method
	 */
	public List getHolidayBookings() {
		return holidayBookings;
	}

	public void addHoliday(float amount, Date date, String description) {

		long currentTime = date.getTime();

		HolidayBooking holiday = new HolidayBooking();
		holiday.setHolidayID(++id);
		holiday
				.setAmount(new DayCount(amount));
		holiday.setDate(new Timestamp(currentTime));
		if (description == null)
			description = "Holiday no " + id;
		holiday.setDescription(description);
		holidayBookings.add(holiday);
	}

	/**
	 * Gets co.uk.realsolve.holiday detail - can return null
	 */
	public HolidayBooking getHoliday(int id) {
		for (Iterator iter = holidayBookings.iterator(); iter.hasNext();) {
			HolidayBooking holiday = (HolidayBooking) iter.next();
			if (holiday.getHolidayID() == id) {
				return holiday;
			}
		}
		return null;
	}

	/** *************** helper methods ******************* */

	/**
	 * Allows you to add a co.uk.realsolve.holiday
	 */
	private void addHoliday(float f, String ref) {
		Date date = new Date();
		addHoliday(f, date, null);
	}

	protected void setHolidayBookings(List holidayBookings) {
		this.holidayBookings = holidayBookings;
	}

	public void deleteHoliday(HolidayBooking currentHolidayBooking) {
		for (Iterator iter = holidayBookings.iterator(); iter.hasNext();) {
			HolidayBooking holiday = (HolidayBooking) iter.next();
			if (holiday.getHolidayID() == currentHolidayBooking.getHolidayID()) {
				iter.remove();
				break;
			}

		}
	}

}